[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# FactSet News client library for Python

[![API Version](https://img.shields.io/badge/api-v1.0.0-blue)](https://developer.factset.com/api-catalog/factset-news-api)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.FactSetNews/0.1.0)](https://pypi.org/project/fds.sdk.FactSetNews/v/0.1.0)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)


The FactSet News API provides access to FactSet’s news alongside business logic that allows users to replicate views and functionality consistent with the experience provided by the Workstation.
This API provides the ability to create views and pull news headlines based on specific filters. There are the filters available for News:

* Watchlists/Indices/Tickers
* Sources
* Company Filters
* Market Topics
* Countries
* Regions


  


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- SDK version: 0.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.FactSetNews==0.1.0
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.FactSetNews==0.1.0
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.FactSetNews
from fds.sdk.FactSetNews.api import filters_api
from fds.sdk.FactSetNews.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.FactSetNews.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.FactSetNews.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.FactSetNews.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = filters_api.FiltersApi(api_client)
    attributes = [
        "structured",
    ] # [str] | Pass a list of filters to return the respective type of filter. Accepted list values are \"structured\" and/or \"flattened\". If no _attributes are specified, all filters will be returned in the response (this is the default response).  (optional)

    try:
        # Retrieve all FactSet News filters
        # example passing only required values which don't have defaults set
        # and optional values
        api_response = api_instance.get_filters(attributes=attributes)

        pprint(api_response)
    except fds.sdk.FactSetNews.ApiException as e:
        print("Exception when calling FiltersApi->get_filters: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Retrieve all FactSet News filters
    #     api_response, http_status_code, response_headers = api_instance.get_filters_with_http_info(attributes=attributes)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.FactSetNews.ApiException as e:
    #     print("Exception when calling FiltersApi->get_filters: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Retrieve all FactSet News filters
    #     async_result = api_instance.get_filters_async(attributes=attributes)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.FactSetNews.ApiException as e:
    #     print("Exception when calling FiltersApi->get_filters: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Retrieve all FactSet News filters
    #     async_result = api_instance.get_filters_with_http_info_async(attributes=attributes)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.FactSetNews.ApiException as e:
    #     print("Exception when calling FiltersApi->get_filters: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.FactSetNews

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.FactSetNews.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.FactSetNews

configuration = fds.sdk.FactSetNews.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.FactSetNews

configuration = fds.sdk.FactSetNews.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.FactSetNews

configuration = fds.sdk.FactSetNews.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/content/news/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*FiltersApi* | [**get_filters**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FiltersApi.md#get_filters) | **GET** /filters | Retrieve all FactSet News filters
*FiltersApi* | [**get_news_filters_categories**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FiltersApi.md#get_news_filters_categories) | **GET** /filters/categories | Retrieve all News filter categories
*FiltersApi* | [**get_news_filters_countries**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FiltersApi.md#get_news_filters_countries) | **GET** /filters/countries | Retrieve all News filter countries
*FiltersApi* | [**get_news_filters_regions**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FiltersApi.md#get_news_filters_regions) | **GET** /filters/regions | Retrieve all News filter regions
*FiltersApi* | [**get_news_filters_sources**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FiltersApi.md#get_news_filters_sources) | **GET** /filters/sources | Retrieve all News filter sources
*FiltersApi* | [**get_news_filters_topics**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FiltersApi.md#get_news_filters_topics) | **GET** /filters/topics | Retrieve all News filter topics
*FiltersApi* | [**get_news_filters_watchlists**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FiltersApi.md#get_news_filters_watchlists) | **GET** /filters/watchlists | Retrieve all News filter watchlists
*HeadlinesApi* | [**get_fact_set_news_headlines**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/HeadlinesApi.md#get_fact_set_news_headlines) | **POST** /headlines | Retrieve FactSet News headlines for the given filters
*HeadlinesApi* | [**get_fact_set_news_headlines_by_view**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/HeadlinesApi.md#get_fact_set_news_headlines_by_view) | **POST** /headlines/view | Retrieve FactSet News headlines for given view
*ViewsApi* | [**create_fact_set_news_view**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/ViewsApi.md#create_fact_set_news_view) | **POST** /views/create | Creates and saves a FactSet News view
*ViewsApi* | [**create_quick_alert_for_view**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/ViewsApi.md#create_quick_alert_for_view) | **POST** /quick-alert/create | Creates a quick-alert for given saved view
*ViewsApi* | [**delete_quickalert_view**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/ViewsApi.md#delete_quickalert_view) | **POST** /quick-alert/delete | Deletes an existing quick alert for a view.
*ViewsApi* | [**delete_view**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/ViewsApi.md#delete_view) | **POST** /views/delete | Deletes an existing App view
*ViewsApi* | [**edit_fact_set_news_view**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/ViewsApi.md#edit_fact_set_news_view) | **POST** /views/update | Edit an existing FactSet News view with filters specified
*ViewsApi* | [**get_fact_set_news_views**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/ViewsApi.md#get_fact_set_news_views) | **GET** /views | Retrieves a list of search views created in News app


## Documentation For Models

 - [CreateOrEditViewBody](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/CreateOrEditViewBody.md)
 - [CreateOrEditViewBodyData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/CreateOrEditViewBodyData.md)
 - [CreateOrEditViewTickers](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/CreateOrEditViewTickers.md)
 - [CreateViewResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/CreateViewResponse.md)
 - [CreateViewResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/CreateViewResponseData.md)
 - [Criteria](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/Criteria.md)
 - [CriteriaDetail](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/CriteriaDetail.md)
 - [CriteriaOneOf](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/CriteriaOneOf.md)
 - [DeleteViewBody](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/DeleteViewBody.md)
 - [DeleteViewBodyData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/DeleteViewBodyData.md)
 - [Error](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/Error.md)
 - [ErrorResponseObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/ErrorResponseObject.md)
 - [FilterCategoriesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterCategoriesResponse.md)
 - [FilterCategoriesResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterCategoriesResponseData.md)
 - [FilterCountriesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterCountriesResponse.md)
 - [FilterCountriesResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterCountriesResponseData.md)
 - [FilterRegionsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterRegionsResponse.md)
 - [FilterRegionsResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterRegionsResponseData.md)
 - [FilterResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterResponse.md)
 - [FilterResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterResponseData.md)
 - [FilterSourcesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterSourcesResponse.md)
 - [FilterSourcesResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterSourcesResponseData.md)
 - [FilterTopicResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterTopicResponse.md)
 - [FilterTopicResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterTopicResponseData.md)
 - [FilterWatchlistsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterWatchlistsResponse.md)
 - [FilterWatchlistsResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FilterWatchlistsResponseData.md)
 - [FlattenedFilters](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FlattenedFilters.md)
 - [FlattenedFiltersCategories](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FlattenedFiltersCategories.md)
 - [FlattenedFiltersCategoriesObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FlattenedFiltersCategoriesObject.md)
 - [FlattenedFiltersCountries](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FlattenedFiltersCountries.md)
 - [FlattenedFiltersCountriesObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FlattenedFiltersCountriesObject.md)
 - [FlattenedFiltersRegions](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FlattenedFiltersRegions.md)
 - [FlattenedFiltersRegionsObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FlattenedFiltersRegionsObject.md)
 - [FlattenedFiltersSources](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FlattenedFiltersSources.md)
 - [FlattenedFiltersSourcesObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FlattenedFiltersSourcesObject.md)
 - [FlattenedFiltersTopics](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FlattenedFiltersTopics.md)
 - [FlattenedFiltersTopicsObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FlattenedFiltersTopicsObject.md)
 - [FlattenedFiltersWatchlists](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FlattenedFiltersWatchlists.md)
 - [FlattenedFiltersWatchlistsObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/FlattenedFiltersWatchlistsObject.md)
 - [HeadlinesRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/HeadlinesRequest.md)
 - [HeadlinesRequestByView](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/HeadlinesRequestByView.md)
 - [HeadlinesRequestByViewData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/HeadlinesRequestByViewData.md)
 - [HeadlinesRequestByViewDataSearchTime](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/HeadlinesRequestByViewDataSearchTime.md)
 - [HeadlinesRequestByViewMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/HeadlinesRequestByViewMeta.md)
 - [HeadlinesRequestByViewMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/HeadlinesRequestByViewMetaPagination.md)
 - [HeadlinesRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/HeadlinesRequestData.md)
 - [HeadlinesRequestDataSearchTime](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/HeadlinesRequestDataSearchTime.md)
 - [HeadlinesRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/HeadlinesRequestMeta.md)
 - [HeadlinesRequestTickersObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/HeadlinesRequestTickersObject.md)
 - [QuickAlertsBody](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/QuickAlertsBody.md)
 - [QuickAlertsBodyData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/QuickAlertsBodyData.md)
 - [QuickAlertsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/QuickAlertsResponse.md)
 - [QuickAlertsResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/QuickAlertsResponseData.md)
 - [RegionObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/RegionObject.md)
 - [SearchResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/SearchResponse.md)
 - [SearchResponseArrayObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/SearchResponseArrayObject.md)
 - [SearchResponseMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/SearchResponseMeta.md)
 - [SearchResponseMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/SearchResponseMetaPagination.md)
 - [StructuredFilters](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFilters.md)
 - [StructuredFiltersCategories](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersCategories.md)
 - [StructuredFiltersCategoriesObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersCategoriesObject.md)
 - [StructuredFiltersChildrenObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersChildrenObject.md)
 - [StructuredFiltersCountries](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersCountries.md)
 - [StructuredFiltersCountriesObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersCountriesObject.md)
 - [StructuredFiltersRegions](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersRegions.md)
 - [StructuredFiltersRegionsObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersRegionsObject.md)
 - [StructuredFiltersSources](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersSources.md)
 - [StructuredFiltersSourcesChildrenObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersSourcesChildrenObject.md)
 - [StructuredFiltersSourcesObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersSourcesObject.md)
 - [StructuredFiltersTopics](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersTopics.md)
 - [StructuredFiltersTopicsObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersTopicsObject.md)
 - [StructuredFiltersWatchlists](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersWatchlists.md)
 - [StructuredFiltersWatchlistsObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/StructuredFiltersWatchlistsObject.md)
 - [Views](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/Views.md)
 - [ViewsObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetNews/v1/docs/ViewsObject.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.FactSetNews.apis and fds.sdk.FactSetNews.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.FactSetNews.api.default_api import DefaultApi`
- `from fds.sdk.FactSetNews.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.FactSetNews
from fds.sdk.FactSetNews.apis import *
from fds.sdk.FactSetNews.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

